% ----------------------
% SS.m
% ----------------------
% computes steady state and fills the values for year 't'
% in:   DF,w
% out:  resid
% ----------------------

function resid = SS(inputs)

global t rho gam sigma psi
global Y Div w theta I J V K H A Omega Q C TB DF edy r
global A_0 alpha LS LD edl ell N NB delta
global epsl parl0 parl1

DF(t)    = inputs(1);
w(t)     = inputs(2);

ell(t)   = (w(t)*theta(t)/parl0)^epsl;
dis_ell  = parl0*(epsl/(1+epsl))*ell(t)^((1+epsl)/epsl)-parl1;
N(t)     = NB(t)/(1-gam(t));
LS(t)    = ell(t)*theta(t)*N(t);
K(t)     = LS(t)*(alpha*A_0/(r(t)+delta))^(1/(1-alpha));
Y(t)     = A_0*K(t)^alpha*LS(t)^(1-alpha);
LD(t)    = Y(t)*(1-alpha)/w(t);
I(t)     = delta*K(t);
J(t)     = 1/2*psi*K(t)*(I(t)/K(t)-delta)^2;
Div(t)   = Y(t)-w(t)*LD(t)-I(t)-J(t);
V(t)     = (1+r(t))/r(t)*Div(t);
H(t)     = (1+r(t))/(r(t)+1-gam(t))*(w(t)*LS(t)-dis_ell*N(t));
A(t)     = DF(t)+V(t);
Omega(t) = 1/(1-(1/(1+rho))^sigma*(1+r(t))^(sigma-1)*gam(t));
Q(t)     = (A(t)+H(t))/Omega(t);
C(t)     = Q(t)+dis_ell*N(t);
TB(t)    = Y(t)-C(t)-I(t)-J(t);
edy(t)   = I(t)+J(t)+C(t)+TB(t)-Y(t);
edl(t)   = LD(t)-LS(t);

resid(1,1) = DF(t)+(1+r(t))/r(t)*TB(t);
resid(2,1) = edl(t);

end