% ----------------------
% findcalib.m
% ----------------------
% computes calibration
% in:   foreignassets
% out:  resid
% ----------------------

function resid = findcalib(foreignassets)

    global gam0 r0 rho sigma psi delta ell0 w0 theta0 N0 Y0 
    global A_0 alpha H0 A0 K0 LS0 LD0 I0 J0 Div0 V0 Omega0 Q0 C0 TB0
    global epsl parl0 parl1
    
    DF0     = foreignassets;
    
    % CALIBRATION OF LABOR SUPPLY MARGIN
    
    % set parl0 in order to reprodcue ell0, FOC ell0
    parl0   = w0*theta0/ell0^(1/epsl);
    % set parl1 in order to normalize effort costs to 0
    parl1   = parl0*(epsl/(1+epsl))*ell0^((1+epsl)/epsl);
    dis_ell = parl0*(epsl/(1+epsl))*ell0^((1+epsl)/epsl)-parl1;
    
    Omega0  = 1/(1-(1/(1+rho))^sigma*(1+r0)^(sigma-1)*gam0);
    LS0     = ell0*theta0*N0;
    LD0     = LS0;
    K0      = (Y0-w0*LS0)/(r0+delta);
    I0      = delta*K0;
    J0      = 1/2*psi*K0*(I0/K0-delta)^2;
    alpha   = (r0+delta)*K0/Y0;
    A_0     = Y0/(K0^alpha*LS0^(1-alpha));
    LD0     = ((1-alpha)*A_0/w0)^(1/alpha)*K0;
    Div0    = Y0-w0*LD0-I0-J0;
    V0      = (1+r0)*Div0/r0;
    H0      = (1+r0)*(w0*LS0-dis_ell*N0)/(r0+1-gam0);
    A0      = DF0+V0;
    Q0      = (A0+H0)/Omega0;
    C0      = Q0 + dis_ell*N0;
    TB0     = Y0-C0-I0-J0;
    resid   = DF0+(1+r0)/r0*TB0;
end